/*
//  matrices_test.c
//  
//
//  Created by Valentin Emiya on 11/03/13.
//  Copyright (c) 2013 CNRS LIF, Aix-Marseille Univ. All rights reserved.
*/

#include <stdio.h>
#include "matrices.h"

int main(){
    /* Programme de test */
    int i, j, k;
    int dimA = 4;
    int dimB [] = {4,5};
    int dimId = 4;
    double **A;
    double **B;
    double **C;
    double **Id;
    
    printf("Création de A et B\n"); 
    A = create_matrix(dimA, dimA);
    B = create_matrix(dimB[0], dimB[1]);
    printf("\n");
    
    printf("Suppression de A et B\n"); 
    free_matrix(A, dimA);
    free_matrix(B, dimB[0]);
    printf("\n");
    
    printf("Création de A et B\n"); 
    A = create_matrix(dimA, dimA);
    B = create_matrix(dimB[0], dimB[1]);
    printf("\n");
    
    printf("Remplissage de A et B\n");
    fill_matrix(A, dimA, dimA);
    fill_matrix(B, dimB[0], dimB[1]);
    printf("\n");
    
    printf("Affichage de A et B\n");
    print_matrix(A, dimA, dimA);
    printf("\n");
    print_matrix(B, dimB[0], dimB[1]);
    printf("\n");
    
    printf("Création et affichage d'une matrice identité %dx%d\n", dimId, dimId);
    Id = create_identity(dimId);
    print_matrix(Id, dimId, dimId);
    printf("\n");
    
    printf("Tr(Id) = %g\n", compute_trace(Id, dimId));
    printf("Tr(A) = %g\n", compute_trace(A, dimA));
    printf("\n");
    
    printf("Calcul de Id x B\n");
    C = compute_product(Id, B, dimId, dimB[0], dimB[1]);
    print_matrix(C, dimId, dimB[1]);
    free_matrix(C, dimId);
    printf("\n");
    
    printf("Calcul de A x Id\n");
    C = compute_product(A, Id, dimA, dimA, dimId);
    print_matrix(C, dimA, dimId);
    free_matrix(C, dimA);
    printf("\n");
    
    printf("Calcul de A x B\n");
    C = compute_product(A, B, dimA, dimB[0], dimB[1]);
    print_matrix(C, dimA, dimB[1]);
    free_matrix(C, dimA);
    printf("\n");
    
    printf("Calcul de I^1\n");
    C = compute_power(Id, dimId, 1);
    print_matrix(C, dimId, dimId);
    free_matrix(C, dimId);
    printf("\n");
    
    printf("Calcul de I^2\n");
    C = compute_power(Id, dimId, 2);
    print_matrix(C, dimId, dimId);
    free_matrix(C, dimId);
    printf("\n");
    
    printf("Calcul de I^5\n");
    C = compute_power(Id, dimId, 5);
    print_matrix(C, dimId, dimId);
    free_matrix(C, dimId);
    printf("\n");
    
    printf("Calcul de A^1\n");
    C = compute_power(A, dimA, 1);
    print_matrix(C, dimA, dimA);
    free_matrix(C, dimA);
    printf("\n");
    
    printf("Calcul de A^2\n");
    C = compute_power(A, dimA, 2);
    print_matrix(C, dimA, dimA);
    free_matrix(C, dimA);
    printf("\n");
    
    printf("Calcul de A^5\n");
    C = compute_power(A, dimA, 5);
    print_matrix(C, dimA, dimA);
    free_matrix(C, dimA);
    printf("\n");
    
    printf("Is Id diagonal? %d\n", is_diagonal(Id, dimId));
    printf("Is A diagonal? %d\n", is_diagonal(A, dimA));
    printf("\n");
    
    printf("C=diag(A)\n");
    C = create_diagonal(A, dimA);
    print_matrix(C, dimA, dimA);
    printf("Is C diagonal? %d\n", is_diagonal(C, dimA));
    printf("\n");
    
    
    printf("Is Id symetric? %d\n", is_symetric(Id, dimId));
    printf("Is A symetric? %d\n", is_symetric(A, dimA));
    printf("Is C symetric? %d\n", is_symetric(C, dimA));
    printf("\n");
    
    if (C)
        for (i=0; i<dimA; i++)
            for (j=0; j<=i; j++)
                C[i][j] = C[j][i] = k++;
    print_matrix(C, dimA, dimA);
    printf("Is C symetric? %d\n", is_symetric(C, dimA));
	free_matrix(C, dimA);
    printf("\n");
    
    free_matrix(A, dimA);
    free_matrix(B, dimB[0]);
    free_matrix(Id, dimId);
    
    return 0;
}
